============
Installation
============

At the command line::

    pip install dbexample

The package doesn't have any dependencies.

If you would like to get access to the database, you also need to install the databroker::

    pip install databroker
